"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lintBinCommand = void 0;
var tslib_1 = require("tslib");
var fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
var path_1 = tslib_1.__importDefault(require("path"));
var eslint_1 = require("eslint");
var lint_config_1 = require("./configs/lint.config");
var messages_1 = require("../../shared/messages");
var package_const_1 = require("../../shared/constants/package.const");
var lint_helpers_1 = require("./lint.helpers");
var lintBinCommand = function (prog) {
    prog
        .command('lint')
        .describe('Lint a package (default lint pattern src/**/*.{js,jsx,ts,tsx}.')
        .alias('l')
        .option('fix', 'Resolve fixable eslint errors')
        .example('lint --fix')
        .option('ignore-path', 'Ignore a path')
        .example('lint --ignore-path src/foo.ts')
        .action(function (opts) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var time, files, _a, dir, project, packageJsonPath, _b, eslintConfig, cli, results, formatter, duration, results_1, results_1_1, result;
        var e_1, _c;
        return tslib_1.__generator(this, function (_d) {
            switch (_d.label) {
                case 0:
                    time = process.hrtime();
                    files = opts._.length > 0 ? opts._ : ['src/**/*.{js,jsx,ts,tsx}'];
                    return [4 /*yield*/, lint_helpers_1.getPackageLintInfo()];
                case 1:
                    _a = _d.sent(), dir = _a.dir, project = _a.project;
                    packageJsonPath = path_1.default.resolve(dir, package_const_1.PACKAGE_JSON);
                    return [4 /*yield*/, fs_extra_1.default.readJSON(packageJsonPath)];
                case 2:
                    _b = (_d.sent()).eslintConfig, eslintConfig = _b === void 0 ? {} : _b;
                    cli = new eslint_1.ESLint({
                        baseConfig: tslib_1.__assign(tslib_1.__assign({}, lint_config_1.createLintConfig(dir, project)), eslintConfig),
                        extensions: ['.ts', '.tsx', '.js', '.jsx'],
                        fix: opts.fix,
                        ignorePath: opts['ignore-path'],
                    });
                    console.log(messages_1.lintMessage.linting(files));
                    return [4 /*yield*/, cli.lintFiles(files)];
                case 3:
                    results = _d.sent();
                    if (!opts.fix) return [3 /*break*/, 5];
                    return [4 /*yield*/, eslint_1.ESLint.outputFixes(results)];
                case 4:
                    _d.sent();
                    _d.label = 5;
                case 5: return [4 /*yield*/, cli.loadFormatter()];
                case 6:
                    formatter = _d.sent();
                    console.log(formatter.format(results));
                    duration = process.hrtime(time);
                    console.log(messages_1.lintMessage.linted(duration));
                    try {
                        for (results_1 = tslib_1.__values(results), results_1_1 = results_1.next(); !results_1_1.done; results_1_1 = results_1.next()) {
                            result = results_1_1.value;
                            if (result.errorCount) {
                                process.exit(1);
                            }
                        }
                    }
                    catch (e_1_1) { e_1 = { error: e_1_1 }; }
                    finally {
                        try {
                            if (results_1_1 && !results_1_1.done && (_c = results_1.return)) _c.call(results_1);
                        }
                        finally { if (e_1) throw e_1.error; }
                    }
                    return [2 /*return*/];
            }
        });
    }); });
};
exports.lintBinCommand = lintBinCommand;
